@@ -46,10 +46,6 @@ enum
 	PROP_MAX_ZOOM
 };
 
-
-static void ephy_zoom_action_init       (EphyZoomAction *action);
-static void ephy_zoom_action_class_init (EphyZoomActionClass *class);
-
 enum
 {
 	ZOOM_TO_LEVEL_SIGNAL,
@@ -58,7 +54,9 @@ enum
 
 static guint signals[LAST_SIGNAL] = { 0 };
 
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
 G_DEFINE_TYPE_WITH_PRIVATE (EphyZoomAction, ephy_zoom_action, GTK_TYPE_ACTION)
+G_GNUC_END_IGNORE_DEPRECATIONS;
 
 static void
 zoom_to_level_cb (EphyZoomControl *control,
@@ -106,8 +104,9 @@ connect_proxy (GtkAction *action, GtkWidget *proxy)
 		g_signal_connect (proxy, "zoom_to_level",
 				  G_CALLBACK (zoom_to_level_cb), action);
 	}
-
+	G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
 	GTK_ACTION_CLASS (ephy_zoom_action_parent_class)->connect_proxy (action, proxy);
+	G_GNUC_END_IGNORE_DEPRECATIONS;
 }
 
 static void
@@ -140,31 +139,33 @@ create_menu_item (GtkAction *action)
 
 	for (i = 0; i < n_zoom_levels; i++)
 	{
-		if (zoom_levels[i].level == EPHY_ZOOM_SEPARATOR) 
+		if (zoom_levels[i].level == EPHY_ZOOM_SEPARATOR)
 		{
 			menu_item = gtk_separator_menu_item_new ();
-		} 
-		else 
+		}
+		else
 		{
-			menu_item = gtk_radio_menu_item_new_with_label (group, 
+			menu_item = gtk_radio_menu_item_new_with_label (group,
 									_(zoom_levels[i].name));
 			group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (menu_item));
 
                         gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_item),
                                                         p->zoom == zoom_levels[i].level);
-        
+
                         g_object_set_data (G_OBJECT (menu_item), "zoom-level", GINT_TO_POINTER (i));
                         g_signal_connect_object (G_OBJECT (menu_item), "activate",
                                                 G_CALLBACK (proxy_menu_activate_cb), action, 0);
                 }
-        
+
                 gtk_widget_show (menu_item);
 		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
 	}
 
 	gtk_widget_show (menu);
 
+	G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
         menu_item = GTK_ACTION_CLASS (ephy_zoom_action_parent_class)->create_menu_item (action);
+	G_GNUC_END_IGNORE_DEPRECATIONS;
 
 	gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_item), menu);
 
@@ -225,7 +226,9 @@ static void
 ephy_zoom_action_class_init (EphyZoomActionClass *class)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (class);
+	G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
 	GtkActionClass *action_class = GTK_ACTION_CLASS (class);
+	G_GNUC_END_IGNORE_DEPRECATIONS;
 
 	object_class->set_property = ephy_zoom_action_set_property;
 	object_class->get_property = ephy_zoom_action_get_property;
@@ -297,7 +300,7 @@ float
 ephy_zoom_action_get_zoom_level (EphyZoomAction *action)
 {
 	g_return_val_if_fail (EPHY_IS_ZOOM_ACTION (action), 1.0);
-	
+
 	return action->priv->zoom;
 }
 
