@@ -43,18 +43,15 @@ static void ev_file_monitor_changed_cb    (GFileMonitor     *monitor,
 					   GFile            *other_file,
 					   GFileMonitorEvent event_type,
 					   EvFileMonitor    *ev_monitor);
-	
-#define EV_FILE_MONITOR_GET_PRIVATE(object) \
-                (G_TYPE_INSTANCE_GET_PRIVATE ((object), EV_TYPE_FILE_MONITOR, EvFileMonitorPrivate))
 
-G_DEFINE_TYPE (EvFileMonitor, ev_file_monitor, G_TYPE_OBJECT)
+G_DEFINE_TYPE_WITH_PRIVATE (EvFileMonitor, ev_file_monitor, G_TYPE_OBJECT)
 
 static guint signals[N_SIGNALS] = { 0 };
 
 static void
 ev_file_monitor_init (EvFileMonitor *ev_monitor)
 {
-	ev_monitor->priv = EV_FILE_MONITOR_GET_PRIVATE (ev_monitor);
+	ev_monitor->priv = ev_file_monitor_get_instance_private (ev_monitor);
 }
 
 static void
@@ -63,7 +60,7 @@ ev_file_monitor_finalize (GObject *object)
 	EvFileMonitor *ev_monitor = EV_FILE_MONITOR (object);
 
 	ev_file_monitor_timeout_stop (ev_monitor);
-	
+
 	if (ev_monitor->priv->monitor) {
 		g_signal_handlers_disconnect_by_func (ev_monitor->priv->monitor,
 						      ev_file_monitor_changed_cb,
@@ -80,8 +77,6 @@ ev_file_monitor_class_init (EvFileMonitorClass *klass)
 {
 	GObjectClass *g_object_class = G_OBJECT_CLASS (klass);
 
-	g_type_class_add_private (g_object_class, sizeof (EvFileMonitorPrivate));
-
 	g_object_class->finalize = ev_file_monitor_finalize;
 
 	/* Signals */
@@ -99,7 +94,7 @@ static gboolean
 timeout_cb (EvFileMonitor *ev_monitor)
 {
 	g_signal_emit (ev_monitor, signals[CHANGED], 0);
-	
+
 	ev_monitor->priv->timeout_id = 0;
 	return FALSE;
 }
@@ -108,7 +103,7 @@ static void
 ev_file_monitor_timeout_start (EvFileMonitor *ev_monitor)
 {
 	ev_file_monitor_timeout_stop (ev_monitor);
-	
+
 	ev_monitor->priv->timeout_id =
 		g_timeout_add_seconds (5, (GSourceFunc)timeout_cb, ev_monitor);
 }
@@ -149,7 +144,7 @@ ev_file_monitor_new (const gchar *uri)
 	EvFileMonitor *ev_monitor;
 	GFile         *file;
 	GError        *error = NULL;
-	
+
 	ev_monitor = EV_FILE_MONITOR (g_object_new (EV_TYPE_FILE_MONITOR, NULL));
 
 	file = g_file_new_for_uri (uri);
