@@ -45,13 +45,10 @@ struct _EvPasswordViewPrivate {
 	GFile        *uri_file;
 };
 
-#define EV_PASSWORD_VIEW_GET_PRIVATE(object) \
-	(G_TYPE_INSTANCE_GET_PRIVATE ((object), EV_TYPE_PASSWORD_VIEW, EvPasswordViewPrivate));
-
 static guint password_view_signals [LAST_SIGNAL] = { 0 };
 
 
-G_DEFINE_TYPE (EvPasswordView, ev_password_view, GTK_TYPE_VIEWPORT)
+G_DEFINE_TYPE_WITH_PRIVATE (EvPasswordView, ev_password_view, GTK_TYPE_VIEWPORT)
 
 static void
 ev_password_view_finalize (GObject *object)
@@ -89,8 +86,6 @@ ev_password_view_class_init (EvPasswordViewClass *class)
 			      g_cclosure_marshal_VOID__VOID,
 			      G_TYPE_NONE, 0);
 
-	g_type_class_add_private (g_object_class, sizeof (EvPasswordViewPrivate));
-
 	g_object_class->finalize = ev_password_view_finalize;
 }
 
@@ -111,7 +106,7 @@ ev_password_view_init (EvPasswordView *password_view)
 	GtkWidget *label;
 	gchar     *markup;
 
-	password_view->priv = EV_PASSWORD_VIEW_GET_PRIVATE (password_view);
+	password_view->priv = ev_password_view_get_instance_private (password_view);
 
 	password_view->priv->password_save = G_PASSWORD_SAVE_NEVER;
 
@@ -140,7 +135,7 @@ ev_password_view_init (EvPasswordView *password_view)
 				  _("This document is locked and can only be read by entering the correct password."));
 	gtk_label_set_markup (GTK_LABEL (label), markup);
 	g_free (markup);
-			      
+
 	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
 
 	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
@@ -189,15 +184,15 @@ ev_password_dialog_got_response (GtkDialog      *dialog,
 				 EvPasswordView *password_view)
 {
 	gtk_widget_set_sensitive (GTK_WIDGET (password_view), TRUE);
-	
+
 	if (response_id == GTK_RESPONSE_OK) {
 		g_free (password_view->priv->password);
 		password_view->priv->password =
 			g_strdup (gtk_entry_get_text (GTK_ENTRY (password_view->priv->password_entry)));
-		
+
 		g_signal_emit (password_view, password_view_signals[UNLOCK], 0);
 	}
-	
+
 	gtk_widget_destroy (GTK_WIDGET (dialog));
 }
 
@@ -207,7 +202,7 @@ ev_password_dialog_remember_button_toggled (GtkToggleButton *button,
 {
 	if (gtk_toggle_button_get_active (button)) {
 		gpointer data;
-		
+
 		data = g_object_get_data (G_OBJECT (button), "password-save");
 		password_view->priv->password_save = GPOINTER_TO_INT (data);
 	}
@@ -243,7 +238,7 @@ ev_password_view_ask_password (EvPasswordView *password_view)
 	gchar     *text, *markup, *file_name;
 
 	gtk_widget_set_sensitive (GTK_WIDGET (password_view), FALSE);
-	
+
 	dialog = GTK_DIALOG (gtk_dialog_new ());
 	content_area = gtk_dialog_get_content_area (dialog);
 	action_area = gtk_dialog_get_action_area (dialog);
@@ -267,7 +262,7 @@ ev_password_view_ask_password (EvPasswordView *password_view)
 	gtk_dialog_set_default_response (dialog, GTK_RESPONSE_OK);
 	gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog),
 					   GTK_RESPONSE_OK, FALSE);
-	
+
 	/* Build contents */
 	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
 	gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
@@ -341,7 +336,7 @@ ev_password_view_ask_password (EvPasswordView *password_view)
 	gtk_grid_attach (GTK_GRID (grid), password_view->priv->password_entry, 1, 0, 1, 1);
 	gtk_widget_set_hexpand (password_view->priv->password_entry, TRUE);
 	gtk_widget_show (password_view->priv->password_entry);
-	
+
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label),
 				       password_view->priv->password_entry);
 
@@ -394,7 +389,7 @@ ev_password_view_ask_password (EvPasswordView *password_view)
 	g_signal_connect (dialog, "response",
 			  G_CALLBACK (ev_password_dialog_got_response),
 			  password_view);
-	
+
 	gtk_widget_show (GTK_WIDGET (dialog));
 }
 
